@@ -21,15 +21,13 @@
  * 	51 Franklin Street, Fifth Floor
  * 	Boston, MA  02110-1301, USA.
  */
-
+ 
 #include <glib.h>
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-debug.h>
 #include "symbol-db-view.h"
 #include "symbol-db-engine.h"
-#include "symbol-db-engine-iterator.h"
-#include "symbol-db-engine-iterator-node.h"
 
 #define DUMMY_SYMBOL_ID		G_MININT32+1
 
@@ -75,20 +73,13 @@ typedef struct _NodeIdleExpand  {
 
 
 static GtkTreeViewClass *parent_class = NULL;
-static GHashTable *pixbufs_hash = NULL;
 static void 
 trigger_on_symbol_inserted (SymbolDBView *dbv, gint symbol_id);
 
 
-static gint
-gtree_compare_func (gconstpointer a, gconstpointer b, gpointer user_data)
-{
-	return (gint)a - (gint)b;
-}
-
 static void
 waiting_for_symbol_destroy (WaitingForSymbol *wfs)
-{
+{	
 	g_return_if_fail (wfs != NULL);
 	g_free (wfs->child_symbol_name);
 	g_free (wfs);
@@ -108,7 +99,7 @@ sdb_view_get_iter_from_row_ref (SymbolDBView *dbv, GtkTreeRowReference *row_ref,
 	path = gtk_tree_row_reference_get_path (row_ref);
 	if (path == NULL) 
 	{
-		DEBUG_PRINT ("sdb_view_get_iter_from_row_ref (): path is null, something "
+		DEBUG_PRINT ("%s", "sdb_view_get_iter_from_row_ref (): path is null, something "
 					 "went wrong ?!");
 		return FALSE;
 	}
@@ -128,7 +119,7 @@ sdb_view_get_iter_from_row_ref (SymbolDBView *dbv, GtkTreeRowReference *row_ref,
 static gboolean
 traverse_free_waiting_for (gpointer key, gpointer value, gpointer data)
 {
-	if (value == NULL)
+	if (value == NULL || key == NULL)
 		return FALSE;
 
 	g_slist_foreach ((GSList*)value, (GFunc)waiting_for_symbol_destroy, NULL);
@@ -150,7 +141,7 @@ symbol_db_view_clear_cache (SymbolDBView *dbv)
 	if (store != NULL)
 		g_object_unref (store);	
 	
-	/* this will free alto the priv->row_ref* instances */	
+	/* this will free also the priv->row_ref* instances */	
 	if (priv->nodes_displayed)
 	{
 		g_tree_destroy (priv->nodes_displayed);
@@ -169,7 +160,7 @@ symbol_db_view_clear_cache (SymbolDBView *dbv)
 }
 
 static void
-on_scan_end (SymbolDBEngine *dbe, gpointer data)
+on_scan_end (SymbolDBEngine *dbe, gint process_id, gpointer data)
 {
 	SymbolDBView *dbv;
 	SymbolDBViewPriv *priv;
@@ -181,7 +172,7 @@ on_scan_end (SymbolDBEngine *dbe, gpointer data)
 	/* void the waiting_for symbols */
 	/* free the waiting_for structs before destroying the tree itself */
 	if (priv->waiting_for)
-	{
+	{		
 		g_tree_foreach (priv->waiting_for, traverse_free_waiting_for, data);
 		g_tree_destroy (priv->waiting_for);
 		
@@ -189,7 +180,7 @@ on_scan_end (SymbolDBEngine *dbe, gpointer data)
 		 * one proposed by the doc is too complex.. create a list of the items
 		 * and reparse them with g_tree_remove...
 		 */
-		priv->waiting_for = g_tree_new_full ((GCompareDataFunc)&gtree_compare_func, 
+		priv->waiting_for = g_tree_new_full ((GCompareDataFunc)&symbol_db_gtree_compare_func, 
 									 NULL,
 									 NULL,
 									 NULL);
@@ -250,7 +241,7 @@ do_add_child_symbol_to_view (SymbolDBView *dbv, gint parent_symbol_id,
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (dbv)));
 
 	/* look up the row ref in the hashtable, then get its associated gtktreeiter */
-	row_ref = g_tree_lookup (priv->nodes_displayed, (gpointer)parent_symbol_id);
+	row_ref = g_tree_lookup (priv->nodes_displayed, GINT_TO_POINTER (parent_symbol_id));
 	
 	if (sdb_view_get_iter_from_row_ref (dbv, row_ref, &iter) == FALSE)
 	{
@@ -296,7 +287,7 @@ add_waiting_for_symbol_to_view (SymbolDBView *dbv, WaitingForSymbol *wfs,
 	symbol_id_added = wfs->child_symbol_id;
 	
 	/* add a new entry on gtree 'nodes_displayed' */
-	g_tree_insert (priv->nodes_displayed, (gpointer)wfs->child_symbol_id, 
+	g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (wfs->child_symbol_id), 
 				   child_tree_row_ref);	
 	
 	/* and now trigger the inserted symbol... (recursive function). */
@@ -316,22 +307,22 @@ trigger_on_symbol_inserted (SymbolDBView *dbv, gint symbol_id)
 	
 	priv = dbv->priv;
 
-/*	DEBUG_PRINT ("trigger_on_symbol_inserted (): triggering %d", symbol_id);*/
+	/*DEBUG_PRINT ("trigger_on_symbol_inserted (): triggering %d", symbol_id);*/
 	
 	/* try to find a waiting for symbol */
-	slist = g_tree_lookup (priv->waiting_for, (gpointer)symbol_id);
+	slist = g_tree_lookup (priv->waiting_for, GINT_TO_POINTER (symbol_id));
 	
 	if (slist == NULL) 
 	{
 		/* nothing waiting for us */
-		/*DEBUG_PRINT ("trigger_on_symbol_inserted (): no children waiting for us...");*/
+		/*DEBUG_PRINT ("%s", "trigger_on_symbol_inserted (): no children waiting for us...");*/
 		return;
 	}
 	else {
 		gint i;
 		gint length = g_slist_length (slist);
 
-/*		DEBUG_PRINT ("trigger_on_symbol_inserted (): consuming slist for parent %d",
+		/*DEBUG_PRINT ("trigger_on_symbol_inserted (): consuming slist for parent %d",
 					 symbol_id);*/
 
 		for (i=0; i < length-1; i++)
@@ -347,7 +338,7 @@ trigger_on_symbol_inserted (SymbolDBView *dbv, gint symbol_id)
 		}
 		
 		/* remove the waiting for key/value */
-		g_tree_remove (priv->waiting_for, (gpointer)symbol_id);		
+		g_tree_remove (priv->waiting_for, GINT_TO_POINTER (symbol_id));
 		g_slist_free (slist);
 	}
 }
@@ -364,6 +355,10 @@ add_new_waiting_for (SymbolDBView *dbv, gint parent_symbol_id,
 	g_return_if_fail (dbv != NULL);	
 	priv = dbv->priv;
 
+	/* we don't want a negative parent_symbol_id */
+	if (parent_symbol_id < 0)
+		return;
+	
 	/* check if we already have some children waiting for a 
 	 * specific father to be inserted, then add this symbol_id to the list 
 	 * (or create a new one)
@@ -375,7 +370,7 @@ add_new_waiting_for (SymbolDBView *dbv, gint parent_symbol_id,
 	wfs->child_symbol_name = g_strdup (symbol_name);
 	wfs->pixbuf = pixbuf;
 				
-	node = g_tree_lookup (priv->waiting_for, (gpointer)parent_symbol_id);
+	node = g_tree_lookup (priv->waiting_for, GINT_TO_POINTER (parent_symbol_id));
 	if (node == NULL) 
 	{
 		/* no lists already set. Create one. */
@@ -383,9 +378,9 @@ add_new_waiting_for (SymbolDBView *dbv, gint parent_symbol_id,
 		slist = g_slist_alloc ();			
 				
 		slist = g_slist_prepend (slist, wfs);
-					
+
 		/* add it to the binary tree. */
-		g_tree_insert (priv->waiting_for, (gpointer)parent_symbol_id, 
+		g_tree_insert (priv->waiting_for, GINT_TO_POINTER (parent_symbol_id), 
 							   slist);
 	}
 	else 
@@ -395,8 +390,8 @@ add_new_waiting_for (SymbolDBView *dbv, gint parent_symbol_id,
 		slist = (GSList*)node;
 		
 		slist = g_slist_prepend (slist, wfs);
-				
-		g_tree_replace (priv->waiting_for, (gpointer)parent_symbol_id, 
+
+		g_tree_replace (priv->waiting_for, GINT_TO_POINTER (parent_symbol_id), 
 						slist);
 	}	
 }
@@ -448,7 +443,7 @@ do_recurse_subtree_and_invalidate (SymbolDBView *dbv,
 						 curr_symbol_id, curr_pixbuf);
 	
 	gtk_tree_store_remove (store, parent_subtree_iter);
-	g_tree_remove (priv->nodes_displayed, (gpointer) curr_symbol_id);
+	g_tree_remove (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id));
 
 	/* don't forget to free this gchar */				   
 	g_free (curr_symbol_name);
@@ -502,7 +497,7 @@ prepare_for_adding (SymbolDBView *dbv, gint parent_symbol_id,
 			{
 				gpointer node;
 				/* Vars/Other may not be displayed already. Check it. */
-				node = g_tree_lookup (priv->nodes_displayed, (gpointer)-ROOT_GLOBAL);
+				node = g_tree_lookup (priv->nodes_displayed, GINT_TO_POINTER (-ROOT_GLOBAL));
 		
 				if (node != NULL) 
 				{
@@ -528,7 +523,7 @@ prepare_for_adding (SymbolDBView *dbv, gint parent_symbol_id,
 		}		
 		
 		/* we'll fake the gpointer to store an int */
-		g_tree_insert (priv->nodes_displayed, (gpointer)symbol_id, 
+		g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (symbol_id), 
 					   curr_tree_row_ref);
 				
 		/* let's trigger the insertion of the symbol_id, there may be some children
@@ -560,7 +555,7 @@ prepare_for_adding (SymbolDBView *dbv, gint parent_symbol_id,
 		/* do we already have that parent_symbol displayed in gtktreeview? 
 		 * If that's the case add it as children.
 		 */
-		node = g_tree_lookup (priv->nodes_displayed, (gpointer)parent_symbol_id);
+		node = g_tree_lookup (priv->nodes_displayed, GINT_TO_POINTER (parent_symbol_id));
 		
 		if (node != NULL) 
 		{
@@ -570,7 +565,7 @@ prepare_for_adding (SymbolDBView *dbv, gint parent_symbol_id,
 				   pixbuf, symbol_name, symbol_id);
 			
 			/* add the children_path to the GTree. */
-			g_tree_insert (priv->nodes_displayed, (gpointer)symbol_id, 
+			g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (symbol_id), 
 						   child_row_ref);
 			trigger_on_symbol_inserted (dbv, symbol_id);
 		}
@@ -644,7 +639,7 @@ on_symbol_inserted (SymbolDBEngine *dbe,
 		symbol_access = symbol_db_engine_iterator_node_get_symbol_extra_string (
 							iter_node, SYMINFO_ACCESS);
 		
-		pixbuf = symbol_db_view_get_pixbuf (symbol_kind, symbol_access);
+		pixbuf = symbol_db_util_get_pixbuf (symbol_kind, symbol_access);
 		symbol_name = symbol_db_engine_iterator_node_get_symbol_name (iter_node);
 		
 		/* check if one of the children [if they exist] of symbol_id are already 
@@ -678,7 +673,7 @@ on_symbol_inserted (SymbolDBEngine *dbe,
 					symbol_db_engine_iterator_node_get_symbol_id (iter_node);
 
 				row_ref = g_tree_lookup (priv->nodes_displayed,
-										 (gpointer)curr_child_id);
+										 GINT_TO_POINTER (curr_child_id));
 				if (row_ref == NULL)
 					continue;
 
@@ -735,7 +730,7 @@ do_recurse_subtree_and_remove (SymbolDBView *dbv,
 	}
 
 	gtk_tree_store_remove (store, parent_subtree_iter);
-	g_tree_remove (priv->nodes_displayed, (gpointer) curr_symbol_id);
+	g_tree_remove (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id));
 
 	/* don't forget to free this gchar */				   
 	g_free (curr_symbol_name);
@@ -758,9 +753,9 @@ on_symbol_removed (SymbolDBEngine *dbe, gint symbol_id, gpointer data)
 
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (dbv)));
 
-	DEBUG_PRINT ("on_symbol_removed (): -global- %d", symbol_id);
+	/*DEBUG_PRINT ("on_symbol_removed (): -global- %d", symbol_id);*/
 
-	row_ref = g_tree_lookup (priv->nodes_displayed, (gpointer)symbol_id);
+	row_ref = g_tree_lookup (priv->nodes_displayed, GINT_TO_POINTER (symbol_id));
 	if (sdb_view_get_iter_from_row_ref (dbv, row_ref, &iter) == FALSE)
 	{
 		return;
@@ -819,13 +814,13 @@ sdb_view_row_expanded_idle_destroy (gpointer data)
 	
 	g_return_if_fail (data != NULL);
 	node_expand = data;	
-	DEBUG_PRINT ("sdb_view_global_row_expanded_idle_destroy ()");
+	DEBUG_PRINT ("%s", "sdb_view_global_row_expanded_idle_destroy ()");
 	dbv = node_expand->dbv;
 	dbe = node_expand->dbe;
 	
 	/* remove from the GTree the ids of the func expanding */
 	g_tree_remove (dbv->priv->expanding_gfunc_ids, 
-				   (gpointer)node_expand->expanded_symbol_id);
+				   GINT_TO_POINTER (node_expand->expanded_symbol_id));
 	
 	if (node_expand->expanded_path != NULL) {
 		gtk_tree_path_free (node_expand->expanded_path);
@@ -866,7 +861,7 @@ sdb_view_row_expanded_idle (gpointer data)
 	
 	iter_node = SYMBOL_DB_ENGINE_ITERATOR_NODE (iterator);			
 	curr_symbol_id = symbol_db_engine_iterator_node_get_symbol_id (iter_node);
-	node = g_tree_lookup (priv->nodes_displayed, (gpointer)curr_symbol_id);
+	node = g_tree_lookup (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id));
 		
 	if (node != NULL) 
 	{
@@ -879,7 +874,7 @@ sdb_view_row_expanded_idle (gpointer data)
 														SYMINFO_KIND);			
 	symbol_access = symbol_db_engine_iterator_node_get_symbol_extra_string (iter_node, 
 														SYMINFO_ACCESS);						
-	pixbuf = symbol_db_view_get_pixbuf (symbol_kind, symbol_access);
+	pixbuf = symbol_db_util_get_pixbuf (symbol_kind, symbol_access);
 	
 	curr_tree_row_ref = do_add_child_symbol_to_view (dbv, 
 										node_expand->expanded_symbol_id, pixbuf, 
@@ -890,7 +885,7 @@ sdb_view_row_expanded_idle (gpointer data)
 	}		
 		
 	/* we'll fake the gpointer to store an int */
-	g_tree_insert (priv->nodes_displayed, (gpointer)curr_symbol_id, 
+	g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id), 
 				   curr_tree_row_ref);			
 			
 	sdb_view_get_iter_from_row_ref (dbv, curr_tree_row_ref, &iter);
@@ -912,21 +907,22 @@ sdb_view_row_expanded_idle (gpointer data)
 	{
 		return TRUE;
 	}
-	else {
+	else 
+	{
 		if (g_tree_lookup (priv->nodes_displayed, 
-						   (gpointer)-node_expand->expanded_symbol_id) == NULL)
+						   GINT_TO_POINTER (-node_expand->expanded_symbol_id)) == NULL)
 		{
 			GtkTreeRowReference *others_row_ref;
 			GtkTreeIter others_dummy_node;
 			others_row_ref = do_add_child_symbol_to_view (dbv, 
 								node_expand->expanded_symbol_id, 
-								symbol_db_view_get_pixbuf ("vars", "others"), 
+								symbol_db_util_get_pixbuf ("vars", "others"), 
 								"Vars/Others", 
 								-node_expand->expanded_symbol_id);
 				
 			/* insert a negative node ... */
 			g_tree_insert (priv->nodes_displayed, 
-							   	(gpointer)-node_expand->expanded_symbol_id, 
+							   	GINT_TO_POINTER (-node_expand->expanded_symbol_id), 
 					   			others_row_ref);		
 			
 			/* ... and a dummy child */			
@@ -955,10 +951,10 @@ sdb_view_namespace_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (dbv)));
 	
-	DEBUG_PRINT ("sdb_view_namespace_row_expanded ");
+	DEBUG_PRINT ("%s", "sdb_view_namespace_row_expanded ");
 
 	/* check if there's another expanding idle_func running */
-	node = g_tree_lookup (priv->expanding_gfunc_ids, (gpointer)expanded_symbol_id);
+	node = g_tree_lookup (priv->expanding_gfunc_ids, GINT_TO_POINTER (expanded_symbol_id));
 	if (node != NULL)
 	{
 		return;
@@ -1004,8 +1000,8 @@ sdb_view_namespace_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 						 (GDestroyNotify) sdb_view_row_expanded_idle_destroy);		
 		
 		/* insert the idle_id into a g_tree */
-		g_tree_insert (priv->expanding_gfunc_ids, (gpointer)expanded_symbol_id, 
-					   (gpointer)idle_id);		
+		g_tree_insert (priv->expanding_gfunc_ids, GINT_TO_POINTER (expanded_symbol_id), 
+					   GINT_TO_POINTER (idle_id));
 	}
 }
 
@@ -1025,10 +1021,10 @@ sdb_view_global_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 	
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (dbv)));
 
-	DEBUG_PRINT ("sdb_view_global_row_expanded ()");
+	DEBUG_PRINT ("%s", "sdb_view_global_row_expanded ()");
 	
 	/* check if there's another expanding idle_func running */
-	node = g_tree_lookup (priv->expanding_gfunc_ids, (gpointer)expanded_symbol_id);
+	node = g_tree_lookup (priv->expanding_gfunc_ids, GINT_TO_POINTER (expanded_symbol_id));
 	if (node != NULL)
 	{
 		return;
@@ -1074,8 +1070,8 @@ sdb_view_global_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 		/* insert the idle_id into a g_tree for (eventually) a later retrieval */
 		DEBUG_PRINT ("Inserting into g_tree expanded_symbol_id %d and idle_id %d", 
 					 expanded_symbol_id, idle_id);
-		g_tree_insert (priv->expanding_gfunc_ids, (gpointer)expanded_symbol_id, 
-					   (gpointer)idle_id);
+		g_tree_insert (priv->expanding_gfunc_ids, GINT_TO_POINTER (expanded_symbol_id), 
+					   GINT_TO_POINTER (idle_id));
 	}	
 }
 
@@ -1096,10 +1092,10 @@ sdb_view_vars_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 	positive_symbol_expanded = -expanded_symbol_id;
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (dbv)));
 	
-	DEBUG_PRINT ("sdb_view_vars_row_expanded ()");
+	DEBUG_PRINT ("%s", "sdb_view_vars_row_expanded ()");
 
 	/* check if there's another expanding idle_func running */
-	node = g_tree_lookup (priv->expanding_gfunc_ids, (gpointer)expanded_symbol_id);
+	node = g_tree_lookup (priv->expanding_gfunc_ids, GINT_TO_POINTER (expanded_symbol_id));
 	if (node != NULL)
 	{
 		return;
@@ -1157,8 +1153,8 @@ sdb_view_vars_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 						 (GDestroyNotify) sdb_view_row_expanded_idle_destroy);		
 		
 		/* insert the idle_id into a g_tree */
-		g_tree_insert (priv->expanding_gfunc_ids, (gpointer)expanded_symbol_id, 
-					   (gpointer)idle_id);
+		g_tree_insert (priv->expanding_gfunc_ids, GINT_TO_POINTER (expanded_symbol_id), 
+					   GINT_TO_POINTER (idle_id));
 	}
 }
 
@@ -1236,7 +1232,7 @@ symbol_db_view_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 		iter_node = SYMBOL_DB_ENGINE_ITERATOR_NODE (iterator);
 		symbol_kind = symbol_db_engine_iterator_node_get_symbol_extra_string (
 							iter_node, SYMINFO_KIND);
-		if (strcmp (symbol_kind, "namespace") == 0)
+		if (g_strcmp0 (symbol_kind, "namespace") == 0)
 		{
 			sdb_view_namespace_row_expanded (dbv, dbe, expanded_iter, 
 											 expanded_symbol_id);
@@ -1278,7 +1274,7 @@ symbol_db_view_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 			 * check if the curr_symbol_id is already displayed. In that case
 			 * skip to the next symbol 
 			 */
-			node = g_tree_lookup (priv->nodes_displayed, (gpointer)curr_symbol_id);
+			node = g_tree_lookup (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id));
 		
 			if (node != NULL) 
 			{
@@ -1287,7 +1283,7 @@ symbol_db_view_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 			
 			/* Step 3 */
 			/* ok we must display this symbol */			
-			pixbuf = symbol_db_view_get_pixbuf (
+			pixbuf = symbol_db_util_get_pixbuf (
 						symbol_db_engine_iterator_node_get_symbol_extra_string (
 							iter_node, SYMINFO_KIND),
 						symbol_db_engine_iterator_node_get_symbol_extra_string (
@@ -1312,7 +1308,7 @@ symbol_db_view_row_expanded (SymbolDBView *dbv, SymbolDBEngine *dbe,
 			/* insert the just append row_ref into the GTree for a quick retrieval
 			 * later 
 			 */
-			g_tree_insert (priv->nodes_displayed, (gpointer)curr_symbol_id, 
+			g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id), 
 						   child_row_ref);
 			
 			/* good. Let's check now for a child (B) of the just appended child (A). 
@@ -1353,7 +1349,7 @@ symbol_db_view_row_collapsed (SymbolDBView *dbv, SymbolDBEngine *dbe,
 	/* do a quick check to see if the collapsed_symbol_id is listed into the
 	 * currently expanding symbols. If that's the case remove the gsource func.
 	 */
-	node = g_tree_lookup (priv->expanding_gfunc_ids, (gpointer)collapsed_symbol_id);
+	node = g_tree_lookup (priv->expanding_gfunc_ids, GINT_TO_POINTER (collapsed_symbol_id));
 	
 	if (node == NULL)
 	{
@@ -1361,8 +1357,8 @@ symbol_db_view_row_collapsed (SymbolDBView *dbv, SymbolDBEngine *dbe,
 		return;
 	}
 	else {		
-		g_source_remove ((gint)node);
-		g_tree_remove (priv->expanding_gfunc_ids, (gpointer)collapsed_symbol_id);
+		g_source_remove (GPOINTER_TO_INT(node));
+		g_tree_remove (priv->expanding_gfunc_ids, GINT_TO_POINTER (collapsed_symbol_id));
 	}	
 }
 
@@ -1407,7 +1403,7 @@ sdb_view_init (SymbolDBView *object)
 	/* create a GTree where to store the row_expanding ids of the gfuncs.
 	 * we would be able then to g_source_remove them on row_collapsed
 	 */
-	priv->expanding_gfunc_ids = g_tree_new_full ((GCompareDataFunc)&gtree_compare_func, 
+	priv->expanding_gfunc_ids = g_tree_new_full ((GCompareDataFunc)&symbol_db_gtree_compare_func, 
 										 NULL, NULL, NULL);
 	
 	/* Tree and his model */
@@ -1450,7 +1446,7 @@ sdb_view_finalize (GObject *object)
 	SymbolDBView *view = SYMBOL_DB_VIEW (object);
 	SymbolDBViewPriv *priv = view->priv;
 
-	DEBUG_PRINT ("finalizing symbol_db_view ()");
+	DEBUG_PRINT ("%s", "finalizing symbol_db_view ()");
 	
 	symbol_db_view_clear_cache (view);
 	
@@ -1501,118 +1497,6 @@ symbol_db_view_get_type (void)
 }
 
 
-#define CREATE_SYM_ICON(N, F) \
-	pix_file = anjuta_res_get_pixmap_file (F); \
-	g_hash_table_insert (pixbufs_hash, \
-					   N, \
-					   gdk_pixbuf_new_from_file (pix_file, NULL)); \
-	g_free (pix_file);
-
-static void
-sdb_view_load_symbol_pixbufs ()
-{
-	gchar *pix_file;
-	
-	if (pixbufs_hash != NULL) 
-	{
-		/* we already have loaded it */
-		return;
-	}
-
-	pixbufs_hash = g_hash_table_new (g_str_hash, g_str_equal);
-
-	CREATE_SYM_ICON ("class",             "element-class-16.png");	
-	CREATE_SYM_ICON ("enum",     	  	  "element-enumeration-16.png");		
-	CREATE_SYM_ICON ("enumerator",     	  "element-enumeration-16.png");	
-	CREATE_SYM_ICON ("function",          "element-method-16.png");	
-	CREATE_SYM_ICON ("interface",         "element-interface-16.png");	
-	CREATE_SYM_ICON ("macro",             "element-event-16.png");	
-	CREATE_SYM_ICON ("namespace",         "element-namespace-16.png");
-	CREATE_SYM_ICON ("none",              "element-literal-16.png");
-	CREATE_SYM_ICON ("struct",            "element-structure-16.png");
-	CREATE_SYM_ICON ("typedef",           "element-literal-16.png");
-	CREATE_SYM_ICON ("union",             "element-structure-16.png");
-	CREATE_SYM_ICON ("variable",          "element-literal-16.png");
-	CREATE_SYM_ICON ("prototype",         "element-interface-16.png");	
-	
-	CREATE_SYM_ICON ("privateclass",      "element-class-16.png");
-	CREATE_SYM_ICON ("privateenum",   	  "element-enumeration-16.png");
-	CREATE_SYM_ICON ("privatefield",   	  "element-event-16.png");
-	CREATE_SYM_ICON ("privatefunction",   "element-method-16.png");
-	CREATE_SYM_ICON ("privateinterface",  "element-interface-16.png");	
-	CREATE_SYM_ICON ("privatemember",     "element-property-16.png");	
-	CREATE_SYM_ICON ("privatemethod",     "element-method-16.png");
-	CREATE_SYM_ICON ("privateproperty",   "element-property-16.png");
-	CREATE_SYM_ICON ("privatestruct",     "element-structure-16.png");
-	CREATE_SYM_ICON ("privateprototype",  "element-interface-16.png");
-
-	CREATE_SYM_ICON ("protectedclass",    "element-class-16.png");	
-	CREATE_SYM_ICON ("protectedenum",     "element-enumeration-16.png");
-	CREATE_SYM_ICON ("protectedfield",    "element-event-16.png");	
-	CREATE_SYM_ICON ("protectedmember",   "element-property-16.png");
-	CREATE_SYM_ICON ("protectedmethod",   "element-method-16.png");
-	CREATE_SYM_ICON ("protectedproperty", "element-property-16.png");
-	CREATE_SYM_ICON ("publicprototype",   "element-interface-16.png");
-	
-	CREATE_SYM_ICON ("publicclass",    	  "element-class-16.png");	
-	CREATE_SYM_ICON ("publicenum",    	  "element-enumeration-16.png");	
-	CREATE_SYM_ICON ("publicfunction",    "element-method-16.png");
-	CREATE_SYM_ICON ("publicmember",      "element-method-16.png");
-	CREATE_SYM_ICON ("publicproperty",    "element-property-16.png");
-	CREATE_SYM_ICON ("publicstruct",      "element-structure-16.png");
-	CREATE_SYM_ICON ("publicprototype",   "element-interface-16.png");
-	
-	/* special icon */
-	CREATE_SYM_ICON ("othersvars",   "element-event-16.png");
-	CREATE_SYM_ICON ("globalglobal", "element-event-16.png");
-}
-
-/**
- * @return The pixbufs. It will initialize pixbufs first if they weren't before
- * @param node_access can be NULL.
- */
-inline const GdkPixbuf* 
-symbol_db_view_get_pixbuf  (const gchar *node_type, const gchar *node_access)
-{
-	gchar *search_node;
-	GdkPixbuf *pix;
-	if (!pixbufs_hash)
-	{
-		sdb_view_load_symbol_pixbufs ();
-	}
-	
-	/*DEBUG_PRINT ("symbol_db_view_get_pixbuf: node_type %s node_access %s",
-				 node_type, node_access);*/
-	
-	g_return_val_if_fail (node_type != NULL, NULL);
-
-	/* is there a better/quicker method to retrieve pixbufs? */
-	if (node_access != NULL)
-	{
-		search_node = g_strdup_printf ("%s%s", node_access, node_type);
-	}
-	else 
-	{ 
-		/* we will not free search_node gchar, so casting here is ok. */
-		search_node = (gchar*)node_type;
-	}
-	pix = GDK_PIXBUF (g_hash_table_lookup (pixbufs_hash, search_node));
-	
-	if (node_access)
-	{
-		g_free (search_node);
-	}
-	
-	if (pix == NULL)
-	{
-		DEBUG_PRINT ("symbol_db_view_get_pixbuf (): no pixbuf for %s %s",					 
-					 node_type, node_access);
-	}
-	
-	return pix;
-}
-
-
 GtkWidget* 
 symbol_db_view_new (void)
 {
@@ -1634,7 +1518,7 @@ symbol_db_view_get_file_and_line (SymbolDBView *dbv, SymbolDBEngine *dbe,
 	if (store)
 	{
 		gint symbol_id;
-		const gchar* relative_file;
+		const gchar* file;
 		SymbolDBEngineIteratorNode *node;
 		
 		gtk_tree_model_get (GTK_TREE_MODEL
@@ -1652,10 +1536,9 @@ symbol_db_view_get_file_and_line (SymbolDBView *dbv, SymbolDBEngine *dbe,
 		if (node != NULL) 
 		{
 			*OUT_line = symbol_db_engine_iterator_node_get_symbol_file_pos (node);
-			relative_file = 
-				symbol_db_engine_iterator_node_get_symbol_extra_string (node,
+			file = symbol_db_engine_iterator_node_get_symbol_extra_string (node,
 															SYMINFO_FILE_PATH);
-			*OUT_file = symbol_db_engine_get_full_local_path (dbe, relative_file);
+			*OUT_file = g_strdup (file);
 			return TRUE;
 		}		
 	}
@@ -1714,7 +1597,7 @@ sdb_view_build_and_display_base_tree (SymbolDBView *dbv, SymbolDBEngine *dbe)
 
 			curr_symbol_id = symbol_db_engine_iterator_node_get_symbol_id (iter_node);
 			
-			pixbuf = symbol_db_view_get_pixbuf (
+			pixbuf = symbol_db_util_get_pixbuf (
 						symbol_db_engine_iterator_node_get_symbol_extra_string (
 							iter_node, SYMINFO_KIND),
 						symbol_db_engine_iterator_node_get_symbol_extra_string (
@@ -1730,7 +1613,7 @@ sdb_view_build_and_display_base_tree (SymbolDBView *dbv, SymbolDBEngine *dbe)
 			}		
 		
 			/* we'll fake the gpointer to store an int */
-			g_tree_insert (priv->nodes_displayed, (gpointer)curr_symbol_id, 
+			g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (curr_symbol_id), 
 						   curr_tree_row_ref);
 
 			if (sdb_view_get_iter_from_row_ref (dbv, curr_tree_row_ref, 
@@ -1739,7 +1622,7 @@ sdb_view_build_and_display_base_tree (SymbolDBView *dbv, SymbolDBEngine *dbe)
 				g_warning ("sdb_view_build_and_display_base_tree (): something "
 						   "went wrong");
 				continue;
-			}
+			} 
 			/* add a dummy child */
 			sdb_view_do_add_hidden_dummy_child (dbv, dbe,
 						&child_iter, curr_symbol_id, FALSE);
@@ -1752,7 +1635,7 @@ sdb_view_build_and_display_base_tree (SymbolDBView *dbv, SymbolDBEngine *dbe)
 	/*
 	 * Good. Add a 'Global' node to the store. 
 	 */
-	global_pixbuf = symbol_db_view_get_pixbuf ("global", "global");
+	global_pixbuf = symbol_db_util_get_pixbuf ("global", "global");
 	
 	global_tree_row_ref = do_add_root_symbol_to_view (dbv, global_pixbuf, 
 											"Global", ROOT_GLOBAL);
@@ -1761,7 +1644,7 @@ sdb_view_build_and_display_base_tree (SymbolDBView *dbv, SymbolDBEngine *dbe)
 	{
 		return;
 	}		
-	g_tree_insert (priv->nodes_displayed, (gpointer)ROOT_GLOBAL, 
+	g_tree_insert (priv->nodes_displayed, GINT_TO_POINTER (ROOT_GLOBAL), 
 					   global_tree_row_ref);
 
 	if (sdb_view_get_iter_from_row_ref (dbv, global_tree_row_ref, 
@@ -1812,19 +1695,19 @@ symbol_db_view_recv_signals_from_engine (SymbolDBView *dbv, SymbolDBEngine *dbe,
 	{
 		gtk_widget_set_sensitive (GTK_WIDGET (dbv), FALSE);
 		
-		if (priv->insert_handler >= 0) 
+		if (priv->insert_handler > 0) 
 		{
 			g_signal_handler_disconnect (G_OBJECT (dbe), priv->insert_handler);
 			priv->insert_handler = 0;
 		}
 
-		if (priv->remove_handler >= 0)
+		if (priv->remove_handler > 0)
 		{
 			g_signal_handler_disconnect (G_OBJECT (dbe), priv->remove_handler);
 			priv->remove_handler = 0;
 		}	
 
-		if (priv->scan_end_handler >= 0)
+		if (priv->scan_end_handler > 0)
 		{
 			g_signal_handler_disconnect (G_OBJECT (dbe), priv->scan_end_handler);
 			priv->scan_end_handler = 0;
@@ -1842,18 +1725,18 @@ symbol_db_view_open (SymbolDBView *dbv, SymbolDBEngine *dbe)
 	
 	priv = dbv->priv;
 
-	DEBUG_PRINT ("symbol_db_view_open ()");
+	/*DEBUG_PRINT ("%s", "symbol_db_view_open ()");*/
 	symbol_db_view_clear_cache (dbv);
 	
 	store = sdb_view_create_new_store ();
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dbv), GTK_TREE_MODEL (store));
 	
-	priv->nodes_displayed = g_tree_new_full ((GCompareDataFunc)&gtree_compare_func, 
+	priv->nodes_displayed = g_tree_new_full ((GCompareDataFunc)&symbol_db_gtree_compare_func, 
 										 NULL,
 										 NULL,
 										 (GDestroyNotify)&gtk_tree_row_reference_free);
 
-	priv->waiting_for = g_tree_new_full ((GCompareDataFunc)&gtree_compare_func, 
+	priv->waiting_for = g_tree_new_full ((GCompareDataFunc)&symbol_db_gtree_compare_func, 
 									 NULL,
 									 NULL,
 									 NULL);
